@@ -71,6 +71,7 @@ gtkspell_error_quark(void) {
 	return q;
 }
 
+#ifndef FIXED_PANGO
 static gboolean
 gtkspell_text_iter_forward_word_end(GtkTextIter *i) {
 	GtkTextIter iter;
@@ -119,6 +120,7 @@ gtkspell_text_iter_backward_word_start(GtkTextIter *i) {
 
 #define gtk_text_iter_backward_word_start gtkspell_text_iter_backward_word_start
 #define gtk_text_iter_forward_word_end gtkspell_text_iter_forward_word_end
+#endif
 
 static void
 check_word(GtkSpell *spell, GtkTextBuffer *buffer,
@@ -620,6 +622,7 @@ gtkspell_new_attach(GtkTextView *view, const gchar *lang, GError **error) {
 
 #ifdef ENABLE_NLS
 	bindtextdomain(PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
 #endif
 
 	if (error)
@@ -707,7 +710,6 @@ gtkspell_free(GtkSpell *spell) {
 
 	gtk_text_buffer_get_bounds(buffer, &start, &end);
 	gtk_text_buffer_remove_tag(buffer, spell->tag_highlight, &start, &end);
-	gtk_text_tag_table_remove(table, spell->tag_highlight);
 
 	gtk_text_buffer_delete_mark(buffer, spell->mark_insert_start);
 	gtk_text_buffer_delete_mark(buffer, spell->mark_insert_end);
